% Last modified: 06/09/2012 by Pete

% trueshape     true shape of obstacle in system [1,5]
%                 1 = circle,
%                 2 = square,
%                 3 = upstream-pointing triangle,
%                 4 = downstream-pointing triangle,
%                 5 = diamond
% Re            Reynolds number [50,100]
% randseed      rng seed for observation noise realization (set to -1 to
%               suppress addition of noise to observations)

function Pete_RunObstacle( trueshape, Re, randseed )

Pete_RunDet( trueshape, Re, randseed )

for i = 1:5
    Pete_RunStoch( trueshape, Re, randseed, i )
end

Pete_RunEns( trueshape, Re, randseed, 1 )

